@@ -1,9 +1,9 @@
 from __future__ import annotations
 
 from workflows.file_task import FileTask
-from workflows.run import run_tasks
 from workflows.task import Task
 
 
-__all__ = ["FileTask", "run_tasks", "Task"]
-__version__ = "0.1.7"
+__all__ = ["FileTask", "Task"]
+__version__ = "0.1.9"
+_ = FileTask.run  # dead: disable
